/**
 * Copyright (c) 2014 - 2019, Nordic Semiconductor ASA
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form, except as embedded into a Nordic
 *    Semiconductor ASA integrated circuit in a product or a software update for
 *    such product, must reproduce the above copyright notice, this list of
 *    conditions and the following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 *
 * 3. Neither the name of Nordic Semiconductor ASA nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 *
 * 4. This software, with or without modification, must only be used with a
 *    Nordic Semiconductor ASA integrated circuit.
 *
 * 5. Any software provided in binary form under this license must not be reverse
 *    engineered, decompiled, modified and/or disassembled.
 *
 * THIS SOFTWARE IS PROVIDED BY NORDIC SEMICONDUCTOR ASA "AS IS" AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NORDIC SEMICONDUCTOR ASA OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */
/** @file
 * @defgroup uart_example_main main.c
 * @{
 * @ingroup uart_example
 * @brief UART Example Application main file.
 *
 * This file contains the source code for a sample application using UART.
 *
 */

#include <stdbool.h>
#include <stdint.h>
#include <stdio.h>
#include "app_error.h"
#include "nrf_delay.h"
#include "nrf.h"
#include "bsp.h"
#include "nrfx_uarte.h"

static nrfx_uarte_t m_uarte = NRFX_UARTE_INSTANCE(1);
static uint8_t rx_buffer[5];

void uart_callback(nrfx_uarte_event_t const * p_event, void *  p_context)
{
    uint32_t err_code;
    
    switch(p_event->type)
    {
        case NRFX_UARTE_EVT_RX_DONE:
            bsp_board_led_invert(BSP_BOARD_LED_0);
            err_code = nrfx_uarte_rx(&m_uarte, rx_buffer, sizeof(rx_buffer));
            APP_ERROR_CHECK(err_code);
        break;
        case NRFX_UARTE_EVT_ERROR:
        default:
        break;
    }

}


/**
 * @brief Function for main application entry.
 */
int main(void)
{
    uint32_t err_code;

    /* Configure board. */
    bsp_board_init(BSP_INIT_LEDS);

    nrfx_uarte_config_t config = NRFX_UARTE_DEFAULT_CONFIG;
    config.pseltxd = TX_PIN_NUMBER;
    config.pselrxd = RX_PIN_NUMBER;
    
    err_code = nrfx_uarte_init(&m_uarte, &config, uart_callback);
    APP_ERROR_CHECK(err_code);

    err_code = nrfx_uarte_rx(&m_uarte, rx_buffer, sizeof(rx_buffer));
    APP_ERROR_CHECK(err_code);


    for (;;)
    {
        __WFE();
    }
}


/** @} */
